@@ -13,7 +13,7 @@ import tifffile
 import cc3d
 from cloudvolume.lib import yellow, Bbox
 
-from chunkflow.lib.bounding_boxes import BoundingBox
+from chunkflow.lib.bounding_boxes import BoundingBox, Cartesian
 
 # from typing import Tuple
 # Offset = Tuple[int, int, int]
@@ -30,12 +30,16 @@ class Chunk(NDArrayOperatorsMixin):
     and `examples<https://docs.scipy.org/doc/numpy/user/basics.dispatch.html#module-numpy.doc.dispatch>`_.
 
     :param array: the data array chunk in a big dataset
-    :param voxel_offset: the offset of this array chunk. 3 numbers: z, y, x
-    :param voxel_size: the size of each voxel, normally with unit of nm. 3 numbers: z, y, x.
+    :param voxel_offset (Cartesian): the offset of this array chunk. 3 numbers: z, y, x
+    :param voxel_size (Cartesian): the size of each voxel, normally with unit of nm. 3 numbers: z, y, x.
     :return: a new chunk with array data and global offset
     """
-    def __init__(self, array: np.ndarray, voxel_offset: tuple = None, voxel_size: tuple = None):
+    def __init__(self, array: np.ndarray, 
+            voxel_offset: Cartesian = None, 
+            voxel_size: Cartesian = None):
+        assert array.ndim >= 3 and array.ndim <= 4
         assert isinstance(array, np.ndarray) or isinstance(array, Chunk)
+        
         self.array = array
         if voxel_offset is None:
             if isinstance(array, Chunk):
@@ -56,8 +60,6 @@ class Chunk(NDArrayOperatorsMixin):
             assert len(voxel_size) == 3
             assert np.alltrue([vs > 0 for vs in voxel_size])
         
-        assert array.ndim >= 3 and array.ndim <= 4
-        
     # One might also consider adding the built-in list type to this
     # list, to support operations like np.add(array_like, list)
     _HANDLED_TYPES = (np.ndarray, Number)
@@ -289,6 +291,9 @@ ends with {cutout_stop}, size is {cutout_size}, voxel size is {voxel_size}.""")
                 f.create_dataset('/unique_nonzeros', data = unique)
         return file_name
 
+    def __len__(self):
+        return len(self.array)
+
     def __array__(self):
         return self.array
     
@@ -481,7 +486,11 @@ ends with {cutout_stop}, size is {cutout_size}, voxel size is {voxel_size}.""")
         ret *= mask
         return Chunk(ret, voxel_offset=self.voxel_offset, voxel_size=self.voxel_size)
 
-    def crop_margin(self, margin_size: tuple = None, output_bbox: BoundingBox=None):
+    def crop_margin(
+            self, 
+            margin_size: tuple = None, 
+            output_bbox: BoundingBox=None
+        ):
 
         if margin_size:
             if len(margin_size) == 3 and self.ndim == 4:
@@ -550,13 +559,18 @@ ends with {cutout_stop}, size is {cutout_size}, voxel size is {voxel_size}.""")
         overlap_slices = self._get_overlap_slices(other.slices)
         self.array[overlap_slices] += other.array[overlap_slices]
 
-    def cutout(self, slices: tuple):
+    def cutout(self, x: Union[tuple, BoundingBox, Bbox]):
         """
         cutout a region of interest from this chunk
 
         :param slices: the global slices of region of interest
         :return: another chunk of region of interest
         """
+        if isinstance(x, BoundingBox) or isinstance(x, Bbox):
+            slices = x.to_slices()
+        else:
+            slices = x
+            
         if len(slices) == self.ndim - 1:
             slices = (slice(0, self.shape[0]), ) + slices
         internalSlices = self._get_internal_slices(slices)
