@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import os
+from pathlib import Path
 from time import time
 
 from typing import Generator, List
@@ -10,6 +11,8 @@ import numpy as np
 import click
 import json
 
+from numpy.lib.arraysetops import isin
+
 from .lib import *
 
 from cloudvolume import CloudVolume
@@ -89,7 +92,7 @@ def generate_tasks(
         grid_size: tuple, file_path: str, queue_name: str, respect_chunk_size: bool,
         aligned_block_size: tuple, task_index_start: tuple, 
         task_index_stop: tuple, disbatch: bool ):
-
+    """Generate a batch of tasks."""
     if mip is None:
         mip = state['mip']
     assert mip >=0 
@@ -102,13 +105,11 @@ def generate_tasks(
         respect_chunk_size=respect_chunk_size,
         aligned_block_size=aligned_block_size
     )
-    # if state['verbose']:
-    bbox_num = len(bboxes)
-    print('total number of tasks: ', bbox_num) 
     
     if task_index_start:
         if task_index_stop is None:
-            task_index_stop = task_index_start + 1
+            # task_index_stop = task_index_start + 1
+            task_index_stop = len(bboxes)
         bboxes = [*bboxes[task_index_start:task_index_stop]]
         logging.info(f'selected task indexes from {task_index_start} to {task_index_stop}')
     elif disbatch:
@@ -124,6 +125,10 @@ def generate_tasks(
             file_path += len(bboxes) + '.npy'
         bboxes.to_file(file_path)
 
+    # if state['verbose']:
+    bbox_num = len(bboxes)
+    print('total number of tasks: ', bbox_num) 
+
     if queue_name is not None:
         queue = SQSQueue(queue_name)
         queue.send_message_list(bboxes)
@@ -186,7 +191,7 @@ def skip_all_zero(tasks, input_chunk_name: str, pre: str, post: str, adjust_size
                     print('create an empty file as mark: ', fname)
                     with open(fname, 'a'):
                         os.utime(fname, None)
-                # label task as None and task will be skipped
+                # target task as None and task will be skipped
                 task = None
         yield task
 
@@ -201,7 +206,7 @@ def skip_none(tasks, input_name: str):
         if task is not None:
             data = task[input_name]
             if data is None:
-                # label task as None and task will be skipped
+                # target task as None and task will be skipped
                 task = None
         yield task
 
@@ -391,6 +396,7 @@ def create_info(tasks,input_chunk_name: str, output_layer_path: str, channel_num
               type=int, default=1, help='number of tasks to do in one run.')
 @generator
 def fetch_task_from_file(file_path: str, job_index: int, slurm_job_array: bool, granularity: int):
+    """Fetch task from a file containing bounding boxes."""
     if(slurm_job_array):
         job_index = int(os.environ['SLURM_ARRAY_TASK_ID'])
     assert job_index is not None
@@ -511,16 +517,21 @@ def create_chunk(tasks, name, size, dtype, all_zero, voxel_offset, voxel_size, o
     type=click.Path(file_okay=True, dir_okay=True, resolve_path=True),
     required=True, help='files containing synapses. Currently support HDF5 and JSON.')
 @click.option('--path-suffix', '-s', type=str, default=None, help='file path suffix.')
+@click.option('--c-order/--f-order', default=True,
+    help='C order or Fortran order in the file. XYZ is Fortran order, ZYX is C order.')
 @click.option('--resolution', '-r', type=int, nargs=3, 
     default=None, callback=default_none, help='resolution of points.')
 @click.option('--output-name', '-o', type=str, default='synapses', help='data name of the result.')
 @operator
-def load_synapses(tasks, name: str, file_path: str, path_suffix: str, resolution: tuple, output_name: str):
+def load_synapses(tasks, name: str, file_path: str, path_suffix: str, c_order: bool, 
+        resolution: tuple, output_name: str):
     """Load synapses formated as JSON or HDF5."""
     for task in tasks:
         if task is not None:
             start = time()
-            if os.path.isdir(file_path):
+            if os.path.isfile(file_path) and (file_path.endswith('.h5') or file_path.endswith('.json')):
+                fname = file_path
+            elif os.path.isdir(file_path):
                 bbox = task['bbox']
                 assert path_suffix is not None
                 fname = os.path.join(file_path, f'{bbox.to_filename()}{path_suffix}')
@@ -529,12 +540,16 @@ def load_synapses(tasks, name: str, file_path: str, path_suffix: str, resolution
                 fname = f'{file_path}{bbox.to_filename()}{path_suffix}'
             else:
                 fname = file_path
-            assert os.path.exists(fname)
+            assert os.path.isfile(fname), f'can not find file: {fname}'
 
             if os.path.getsize(fname) == 0:
                 task[output_name] = None
             else:
-                task[output_name] = Synapses.from_file(fname, resolution = resolution)
+                task[output_name] = Synapses.from_file(
+                    fname, 
+                    resolution = resolution,
+                    c_order = c_order
+                )
             
             task['log']['timer'][name] = time() - start
         yield task
@@ -793,11 +808,11 @@ def read_h5(tasks, name: str, file_name: str, dataset_path: str,
 
 
 @main.command('write-h5')
-@click.option('--input-chunk-name', '-i',
+@click.option('--input-name', '-i',
               type=str, default='chunk', help='input chunk name')
 @click.option('--file-name', '-f',
               type=click.Path(dir_okay=True, resolve_path=False), required=True,
-              help='file name of hdf5 file.')
+              help='file name or prefix of output HDF5 file.')
 @click.option('--chunk-size', '-s', type=int, nargs=3,
               default=None, callback=default_none,
               help='save the big volume as chunks.')
@@ -809,16 +824,31 @@ def read_h5(tasks, name: str, file_name: str, dataset_path: str,
     default=None, type=int, callback=default_none, nargs=3,
     help='voxel size of this chunk.'
 )
+@click.option('--touch/--no-touch', default=True, 
+help = 'create an empty file if the input is None.'
+)
 @operator
-def write_h5(tasks, input_chunk_name, file_name, chunk_size, compression, with_offset, voxel_size):
+def write_h5(tasks, input_name, file_name, chunk_size, compression, with_offset, voxel_size, touch):
     """Write chunk to HDF5 file."""
     for task in tasks:
         if task is not None:
-            task[input_chunk_name].to_h5(
-                file_name, with_offset, 
-                chunk_size=chunk_size, 
-                compression=compression,
-                voxel_size=voxel_size)
+            if not file_name.endswith('.h5'):
+                bbox = task['bbox']
+                file_name = f'{file_name}{bbox.to_filename()}.h5'
+            data = task[input_name]
+            if isinstance(data, Chunk):
+                data.to_h5(
+                    file_name, with_offset, 
+                    chunk_size=chunk_size, 
+                    compression=compression,
+                    voxel_size=voxel_size)
+            elif isinstance(data, Synapses):
+                data.to_h5(file_name)
+            elif data is None:
+                if touch:
+                    Path(file_name).touch()
+            else:
+                raise ValueError(f'unsuported type of input data: {data}')
         yield task
 
 
@@ -1240,7 +1270,7 @@ def plugin(tasks, name: str, input_names: str, output_names: str, file: str, arg
 
 @main.command('connected-components')
 @click.option('--name', type=str, default='connected-components', 
-              help='threshold a map and get the labels.')
+              help='threshold a map and get the targets.')
 @click.option('--input-chunk-name', '-i',
               type=str, default=DEFAULT_CHUNK_NAME, 
               help='input chunk name')
@@ -1632,7 +1662,7 @@ def write_precomputed(tasks, name: str, volume_path: str,
 
 @main.command('threshold')
 @click.option('--name', type=str, default='threshold', 
-              help='threshold a map and get the labels.')
+              help='threshold a map and get the targets.')
 @click.option('--input-chunk-name', '-i',
               type=str, default=DEFAULT_CHUNK_NAME, 
               help='input chunk name')
