@@ -15,14 +15,12 @@ class MaskOperator(OperatorBase):
                  chunk_mip: int,
                  inverse: bool = False,
                  fill_missing: bool = False,
-                 check_all_zero=False,
                  name: str = 'mask'):
         super().__init__(name=name)
 
         self.mask_mip = mask_mip
         self.chunk_mip = chunk_mip
         self.inverse = inverse
-        self.check_all_zero = check_all_zero
         
         self.mask_vol = CloudVolume(volume_path,
                                     bounded=False,
@@ -46,7 +44,6 @@ class MaskOperator(OperatorBase):
             logging.warning("chunk is all black, return directly")
             return chunk
 
-        
         mask_in_high_mip = self._read_mask_in_high_mip(chunk.bbox, factor)
 
         if np.alltrue(mask_in_high_mip == 0):
@@ -90,7 +87,7 @@ class MaskOperator(OperatorBase):
         # which will make np.alltrue(mask_in_high_mip == 0) to be
         # VolumeCutout(False) rather than False, so we need to transform it 
         # to numpy
-        mask = mask.astype(np.bool)
+        mask = mask.astype(bool)
         mask = np.asarray(mask)
         mask = np.transpose(mask)
         mask = np.squeeze(mask, axis=0)
