@@ -1,8 +1,4 @@
 # coding=utf-8
-"""
-Note that this code is copied from [gala](https://github.com/janelia-flyem/gala)
-The license is BSD-like [Janelia Farm license](http://janelia-flyem.github.io/janelia_farm_license.html)
-"""
 
 import numpy as np
 import multiprocessing
